# Copyright 1999-2007 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit elisp subversion

ESVN_REPO_URI="http://supercollider.svn.sourceforge.net/svnroot/supercollider/trunk"
#ESVN_STORE_DIR="${DISTDIR}/svn-src"
#ESVN_FETCH_CMD="svn checkout"
#ESVN_UPDATE_CMD="svn update"
#ESVN_PROJECT="${PN/-svn}"
#ESVN_BOOTSTRAP="autogen.sh"
#ESVN_PATCHES=""

DESCRIPTION="An envirnment and a programming language for real time audio synthesis."
HOMEPAGE="http://www.audiosynth.com http://supercollider.sourceforge.net"
SRC_URI=""

LICENSE="GPL-2"
SLOT="0"
KEYWORDS=""

FEATURES="-ccache"
# lid means linux input device support.
IUSE="sse emacs lid devel debug pentium4"

DEPEND="${RDEPEND}
	sys-apps/sed
	sys-devel/automake
	dev-util/scons
	emacs? ( virtual/emacs )"

RDEPEND="media-sound/jack-audio-connection-kit
	media-libs/alsa-lib
	media-libs/libsndfile"

src_compile() {
	# Uncommenting a line per linux/examples/sclang.cfg.in
	if ! use emacs; then
		sed -ie "/#-@SC_LIB_DIR@\/Common\/GUI\/Document.sc/s/^#//" \
			${S}/linux/examples/sclang.cfg.in ||
			die "sed failed."
	else
		sed -e "/elisp_dir = os.path.join(INSTALL_PREFIX/s/site-lisp')/site-lisp','scel')/" \
		-i ${S}/SConstruct ||
		die "modifying elisp installdir failed."
	fi

	local myconf
	if ! use emacs; then
		myconf='SCEL=no'
	fi
	if use sse ;then
		myconf="${myconf} SSE=yes \
			CUSTOMCCFLAGS=-I$(dirname $(gcc-config -X)) \
			CUSTOMCXXFLAGS=-I$(dirname $(gcc-config -X))"
	fi
	if use pentium4 ;then
		myconf="${myconf} OPT_ARCH=pentium4"
	fi
	if use debug ;then
		myconf="${myconf} DEBUG=yes"
	fi
	if use lid ;then
		myconf="${myconf} LID=yes"
	fi
	if use devel;then
		myconf="${myconf} DEVELOPMENT=yes"
	fi
	mkdir ${D}
	scons CUSTOMCCFLAGS="${CFLAGS}" CUSTOMCXXFLAGS="${CXXFLAGS}" \
		PREFIX=/usr DESTDIR=${D} ${myconf} || die "scons failed."
}

src_install() {
	# Main install
	scons install

	# Install our config file
	insinto /etc/supercollider
	doins linux/examples/sclang.cfg

	# Documentation
	mv linux/README linux/README-linux
	mv linux/scel/README linux/scel/README-scel
	dodoc COPYING linux/README-linux linux/scel/README-scel

	# Our documentation
	sed -e "s:@DOCBASE@:/usr/share/doc/${PF}:" < ${FILESDIR}/README-gentoo.txt | gzip > ${D}/usr/share/doc/${PF}/README-gentoo.txt.gz

	# Example files (don't gzip)
	insinto /usr/share/doc/${PF}/examples
	doins linux/examples/onetwoonetwo.sc linux/examples/sclang.sc

	use emacs && elisp-site-file-install ${FILESDIR}/70scel-gentoo.el
}

pkg_postinst() {
	einfo
	einfo "Notice: SuperCollider is not very intuitive to get up and running."
	einfo "The best course of action to make sure that the installation was"
	einfo "successful and get you started with using SuperCollider is to take"
	einfo "a look through /usr/share/doc/${PF}/README-gentoo.txt.gz"
	einfo
}

